
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { Event } from 'vscode/vscode/vs/base/common/event';
import { assertIsDefined } from 'vscode/vscode/vs/base/common/types';
import 'vscode/vscode/vs/platform/instantiation/common/extensions';
import { IInstantiationService } from 'vscode/vscode/vs/platform/instantiation/common/instantiation';
import { AuxiliaryBarPart } from '@codingame/monaco-vscode-6980eeab-47bb-5a48-8e15-32caf0785565-common/vscode/vs/workbench/browser/parts/auxiliarybar/auxiliaryBarPart';
import { PanelPart } from '@codingame/monaco-vscode-6980eeab-47bb-5a48-8e15-32caf0785565-common/vscode/vs/workbench/browser/parts/panel/panelPart';
import { SidebarPart } from '@codingame/monaco-vscode-6980eeab-47bb-5a48-8e15-32caf0785565-common/vscode/vs/workbench/browser/parts/sidebar/sidebarPart';
import { ViewContainerLocation, ViewContainerLocations } from 'vscode/vscode/vs/workbench/common/views';
import { Disposable, DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';

let PaneCompositePartService = class PaneCompositePartService extends Disposable {
    constructor(instantiationService) {
        super();
        this.paneCompositeParts = ( new Map());
        const panelPart = instantiationService.createInstance(PanelPart);
        const sideBarPart = instantiationService.createInstance(SidebarPart);
        const auxiliaryBarPart = instantiationService.createInstance(AuxiliaryBarPart);
        this.paneCompositeParts.set(ViewContainerLocation.Panel, panelPart);
        this.paneCompositeParts.set(ViewContainerLocation.Sidebar, sideBarPart);
        this.paneCompositeParts.set(ViewContainerLocation.AuxiliaryBar, auxiliaryBarPart);
        const eventDisposables = this._register(( new DisposableStore()));
        this.onDidPaneCompositeOpen = Event.any(...( ViewContainerLocations.map(loc => ( Event.map(
            this.paneCompositeParts.get(loc).onDidPaneCompositeOpen,
            composite => { return { composite, viewContainerLocation: loc }; },
            eventDisposables
        )))));
        this.onDidPaneCompositeClose = Event.any(...( ViewContainerLocations.map(loc => ( Event.map(
            this.paneCompositeParts.get(loc).onDidPaneCompositeClose,
            composite => { return { composite, viewContainerLocation: loc }; },
            eventDisposables
        )))));
    }
    openPaneComposite(id, viewContainerLocation, focus) {
        return this.getPartByLocation(viewContainerLocation).openPaneComposite(id, focus);
    }
    getActivePaneComposite(viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getActivePaneComposite();
    }
    getPaneComposite(id, viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getPaneComposite(id);
    }
    getPaneComposites(viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getPaneComposites();
    }
    getPinnedPaneCompositeIds(viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getPinnedPaneCompositeIds();
    }
    getVisiblePaneCompositeIds(viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getVisiblePaneCompositeIds();
    }
    getPaneCompositeIds(viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getPaneCompositeIds();
    }
    getProgressIndicator(id, viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getProgressIndicator(id);
    }
    hideActivePaneComposite(viewContainerLocation) {
        this.getPartByLocation(viewContainerLocation).hideActivePaneComposite();
    }
    getLastActivePaneCompositeId(viewContainerLocation) {
        return this.getPartByLocation(viewContainerLocation).getLastActivePaneCompositeId();
    }
    getPartByLocation(viewContainerLocation) {
        return assertIsDefined(this.paneCompositeParts.get(viewContainerLocation));
    }
};
PaneCompositePartService = ( __decorate([
    ( __param(0, IInstantiationService))
], PaneCompositePartService));

export { PaneCompositePartService };
