import { Disposable } from "vscode/vscode/vs/base/common/lifecycle";
import { URI, UriComponents } from "vscode/vscode/vs/base/common/uri";
import { IInstantiationService } from "vscode/vscode/vs/platform/instantiation/common/instantiation";
import { IWorkbenchContribution } from "vscode/vscode/vs/workbench/common/contributions";
import { EditorInput } from "vscode/vscode/vs/workbench/common/editor/editorInput";
import { CustomEditorInput } from "@codingame/monaco-vscode-7f39b6f1-3542-5430-8760-0f404d7a7cee-common/vscode/vs/workbench/contrib/customEditor/browser/customEditorInput";
import { ICustomEditorService } from "vscode/vscode/vs/workbench/contrib/customEditor/common/customEditor.service";
import { IWebviewService } from "vscode/vscode/vs/workbench/contrib/webview/browser/webview.service";
import { DeserializedWebview, SerializedWebview, SerializedWebviewOptions, WebviewEditorInputSerializer } from "../../webviewPanel/browser/webviewEditorInputSerializer.js";
import { IWebviewWorkbenchService } from "vscode/vscode/vs/workbench/contrib/webviewPanel/browser/webviewWorkbenchService.service";
import { IWorkingCopyBackupMeta, IWorkingCopyIdentifier } from "@codingame/monaco-vscode-a4683c2b-a0d2-5112-96ba-eedc605346d2-common/vscode/vs/workbench/services/workingCopy/common/workingCopy";
import { IWorkingCopyBackupService } from "vscode/vscode/vs/workbench/services/workingCopy/common/workingCopyBackup.service";
import { IWorkingCopyEditorHandler } from "@codingame/monaco-vscode-working-copy-service-override/vscode/vs/workbench/services/workingCopy/common/workingCopyEditorService";
import { IWorkingCopyEditorService } from "vscode/vscode/vs/workbench/services/workingCopy/common/workingCopyEditorService.service";
export interface CustomDocumentBackupData extends IWorkingCopyBackupMeta {
    readonly viewType: string;
    readonly editorResource: UriComponents;
    backupId: string;
    readonly extension: undefined | {
        readonly location: UriComponents;
        readonly id: string;
    };
    readonly webview: {
        readonly origin: string | undefined;
        readonly options: SerializedWebviewOptions;
        readonly state: any;
    };
}
interface SerializedCustomEditor extends SerializedWebview {
    readonly editorResource: UriComponents;
    readonly dirty: boolean;
    readonly backupId?: string;
}
interface DeserializedCustomEditor extends DeserializedWebview {
    readonly editorResource: URI;
    readonly dirty: boolean;
    readonly backupId?: string;
}
export declare class CustomEditorInputSerializer extends WebviewEditorInputSerializer {
    private readonly _instantiationService;
    private readonly _webviewService;
    static readonly ID = "workbench.editors.webviewEditor";
    constructor(webviewWorkbenchService: IWebviewWorkbenchService, _instantiationService: IInstantiationService, _webviewService: IWebviewService);
    serialize(input: CustomEditorInput): string | undefined;
    protected fromJson(data: SerializedCustomEditor): DeserializedCustomEditor;
    deserialize(_instantiationService: IInstantiationService, serializedEditorInput: string): CustomEditorInput;
}
export declare class ComplexCustomWorkingCopyEditorHandler extends Disposable implements IWorkbenchContribution, IWorkingCopyEditorHandler {
    private readonly _instantiationService;
    private readonly _workingCopyBackupService;
    private readonly _webviewService;
    static readonly ID = "workbench.contrib.complexCustomWorkingCopyEditorHandler";
    constructor(_instantiationService: IInstantiationService, _workingCopyEditorService: IWorkingCopyEditorService, _workingCopyBackupService: IWorkingCopyBackupService, _webviewService: IWebviewService, _customEditorService: ICustomEditorService);
    handles(workingCopy: IWorkingCopyIdentifier): boolean;
    isOpen(workingCopy: IWorkingCopyIdentifier, editor: EditorInput): boolean;
    createEditor(workingCopy: IWorkingCopyIdentifier): Promise<EditorInput>;
}
export {};
