import { Dimension } from "vscode/vscode/vs/base/browser/dom";
import { CancellationToken } from "vscode/vscode/vs/base/common/cancellation";
import { Event } from "vscode/vscode/vs/base/common/event";
import { Disposable } from "vscode/vscode/vs/base/common/lifecycle";
import { IObservable } from "vscode/vscode/vs/base/common/observable";
import { URI } from "vscode/vscode/vs/base/common/uri";
import { ICodeEditor } from "vscode/vscode/vs/editor/browser/editorBrowser";
import { ICodeEditorService } from "vscode/vscode/vs/editor/browser/services/codeEditorService";
import { IEditorOptions as ICodeEditorOptions } from "vscode/vscode/vs/editor/common/config/editorOptions";
import { ICodeEditorViewState } from "vscode/vscode/vs/editor/common/editorCommon";
import { ITextResourceConfigurationService } from "vscode/vscode/vs/editor/common/services/textResourceConfiguration";
import { IConfigurationService } from "vscode/vscode/vs/platform/configuration/common/configuration.service";
import { IContextKeyService } from "vscode/vscode/vs/platform/contextkey/common/contextkey.service";
import { IEditorOptions, ITextEditorOptions } from "vscode/vscode/vs/platform/editor/common/editor";
import { IFileService } from "vscode/vscode/vs/platform/files/common/files.service";
import { IInstantiationService } from "vscode/vscode/vs/platform/instantiation/common/instantiation";
import { IStorageService } from "vscode/vscode/vs/platform/storage/common/storage.service";
import { ITelemetryService } from "vscode/vscode/vs/platform/telemetry/common/telemetry.service";
import { IThemeService } from "vscode/vscode/vs/platform/theme/common/themeService.service";
import { AbstractTextEditor } from "@codingame/monaco-vscode-219d9a5f-b446-507b-a188-1178a0867c75-common/vscode/vs/workbench/browser/parts/editor/textEditor";
import { IEditorOpenContext } from "vscode/vscode/vs/workbench/common/editor";
import { EditorInput } from "vscode/vscode/vs/workbench/common/editor/editorInput";
import { IMergeEditorInputModel } from "@codingame/monaco-vscode-8ccb7637-50ea-5359-97bf-00015d7fe567-common/vscode/vs/workbench/contrib/mergeEditor/browser/mergeEditorInputModel";
import { MergeEditorModel } from "@codingame/monaco-vscode-8ccb7637-50ea-5359-97bf-00015d7fe567-common/vscode/vs/workbench/contrib/mergeEditor/browser/model/mergeEditorModel";
import { MergeEditorViewModel } from "./viewModel.js";
import { MergeEditorLayoutKind } from "@codingame/monaco-vscode-897bebad-39df-57cb-8a57-36a271d038be-common/vscode/vs/workbench/contrib/mergeEditor/common/mergeEditor";
import { IEditorGroup } from "vscode/vscode/vs/workbench/services/editor/common/editorGroupsService";
import { IEditorGroupsService } from "vscode/vscode/vs/workbench/services/editor/common/editorGroupsService.service";
import { IEditorResolverService } from "vscode/vscode/vs/workbench/services/editor/common/editorResolverService.service";
import { IEditorService } from "vscode/vscode/vs/workbench/services/editor/common/editorService.service";
export declare class MergeEditor extends AbstractTextEditor<IMergeEditorViewState> {
    private readonly contextKeyService;
    private readonly _configurationService;
    private readonly _codeEditorService;
    private readonly configurationService;
    static readonly ID = "mergeEditor";
    private readonly _sessionDisposables;
    private readonly _viewModel;
    get viewModel(): IObservable<MergeEditorViewModel | undefined>;
    private rootHtmlElement;
    private readonly _grid;
    private readonly input1View;
    private readonly baseView;
    private readonly baseViewOptions;
    private readonly input2View;
    private readonly inputResultView;
    private readonly _layoutMode;
    private readonly _layoutModeObs;
    private readonly _ctxIsMergeEditor;
    private readonly _ctxUsesColumnLayout;
    private readonly _ctxShowBase;
    private readonly _ctxShowBaseAtTop;
    private readonly _ctxResultUri;
    private readonly _ctxBaseUri;
    private readonly _ctxShowNonConflictingChanges;
    private readonly _inputModel;
    get inputModel(): IObservable<IMergeEditorInputModel | undefined>;
    get model(): MergeEditorModel | undefined;
    private get inputsWritable();
    private readonly viewZoneComputer;
    protected readonly codeLensesVisible: IObservable<boolean, unknown>;
    private readonly scrollSynchronizer;
    constructor(group: IEditorGroup, instantiation: IInstantiationService, contextKeyService: IContextKeyService, telemetryService: ITelemetryService, storageService: IStorageService, themeService: IThemeService, textResourceConfigurationService: ITextResourceConfigurationService, _configurationService: IConfigurationService, editorService: IEditorService, editorGroupService: IEditorGroupsService, fileService: IFileService, _codeEditorService: ICodeEditorService, configurationService: IConfigurationService);
    dispose(): void;
    private readonly _onDidChangeSizeConstraints;
    readonly onDidChangeSizeConstraints: Event<void>;
    get minimumWidth(): number;
    getTitle(): string;
    protected createEditorControl(parent: HTMLElement, initialOptions: ICodeEditorOptions): void;
    protected updateEditorControlOptions(options: ICodeEditorOptions): void;
    private applyOptions;
    protected getMainControl(): ICodeEditor | undefined;
    layout(dimension: Dimension): void;
    setInput(input: EditorInput, options: IEditorOptions | undefined, context: IEditorOpenContext, token: CancellationToken): Promise<void>;
    private setViewZones;
    setOptions(options: ITextEditorOptions | undefined): void;
    clearInput(): void;
    focus(): void;
    hasFocus(): boolean;
    protected setEditorVisible(visible: boolean): void;
    getControl(): ICodeEditor | undefined;
    get scopedContextKeyService(): IContextKeyService | undefined;
    toggleBase(): void;
    toggleShowBaseTop(): void;
    toggleShowBaseCenter(): void;
    setLayoutKind(kind: MergeEditorLayoutKind): void;
    setLayout(newLayout: IMergeEditorLayout): void;
    private readonly baseViewDisposables;
    private applyLayout;
    private setGrid;
    private _applyViewState;
    protected computeEditorViewState(resource: URI): IMergeEditorViewState | undefined;
    protected tracksEditorViewState(input: EditorInput): boolean;
    private readonly showNonConflictingChangesStore;
    private readonly showNonConflictingChanges;
    toggleShowNonConflictingChanges(): void;
}
export interface IMergeEditorLayout {
    readonly kind: MergeEditorLayoutKind;
    readonly showBase: boolean;
    readonly showBaseAtTop: boolean;
}
export declare class MergeEditorOpenHandlerContribution extends Disposable {
    private readonly _editorService;
    constructor(_editorService: IEditorService, codeEditorService: ICodeEditorService);
    private openCodeEditorFromMergeEditor;
}
export declare class MergeEditorResolverContribution extends Disposable {
    static readonly ID = "workbench.contrib.mergeEditorResolver";
    constructor(editorResolverService: IEditorResolverService, instantiationService: IInstantiationService);
}
type IMergeEditorViewState = ICodeEditorViewState & {
    readonly input1State?: ICodeEditorViewState;
    readonly input2State?: ICodeEditorViewState;
    readonly focusIndex: number;
};
export {};
