import { URI } from "vscode/vscode/vs/base/common/uri";
import { IInstantiationService } from "vscode/vscode/vs/platform/instantiation/common/instantiation";
import { UntitledTextEditorModel, IUntitledTextEditorModel } from "@codingame/monaco-vscode-0c06bfba-d24d-5c4d-90cd-b40cefb7f811-common/vscode/vs/workbench/services/untitled/common/untitledTextEditorModel";
import { IConfigurationService } from "vscode/vscode/vs/platform/configuration/common/configuration.service";
import { Event } from "vscode/vscode/vs/base/common/event";
import { Disposable } from "vscode/vscode/vs/base/common/lifecycle";
import { IUntitledTextEditorService } from "vscode/vscode/vs/workbench/services/untitled/common/untitledTextEditorService.service";
export interface INewUntitledTextEditorOptions {
    initialValue?: string;
    languageId?: string;
    encoding?: string;
}
export interface IExistingUntitledTextEditorOptions extends INewUntitledTextEditorOptions {
    untitledResource?: URI;
}
export interface INewUntitledTextEditorWithAssociatedResourceOptions extends INewUntitledTextEditorOptions {
    associatedResource?: {
        authority: string;
        path: string;
        query: string;
        fragment: string;
    };
}
type IInternalUntitledTextEditorOptions = IExistingUntitledTextEditorOptions & INewUntitledTextEditorWithAssociatedResourceOptions;
export interface IUntitledTextEditorModelManager {
    readonly onDidChangeDirty: Event<IUntitledTextEditorModel>;
    readonly onDidChangeEncoding: Event<IUntitledTextEditorModel>;
    readonly onDidChangeLabel: Event<IUntitledTextEditorModel>;
    readonly onDidCreate: Event<IUntitledTextEditorModel>;
    readonly onWillDispose: Event<IUntitledTextEditorModel>;
    create(options?: INewUntitledTextEditorOptions): IUntitledTextEditorModel;
    create(options?: INewUntitledTextEditorWithAssociatedResourceOptions): IUntitledTextEditorModel;
    create(options?: IExistingUntitledTextEditorOptions): IUntitledTextEditorModel;
    get(resource: URI): IUntitledTextEditorModel | undefined;
    getValue(resource: URI): string | undefined;
    resolve(options?: INewUntitledTextEditorOptions): Promise<IUntitledTextEditorModel>;
    resolve(options?: INewUntitledTextEditorWithAssociatedResourceOptions): Promise<IUntitledTextEditorModel>;
    resolve(options?: IExistingUntitledTextEditorOptions): Promise<IUntitledTextEditorModel>;
    isUntitledWithAssociatedResource(resource: URI): boolean;
    canDispose(model: IUntitledTextEditorModel): true | Promise<true>;
}
export declare class UntitledTextEditorService extends Disposable implements IUntitledTextEditorService {
    private readonly instantiationService;
    private readonly configurationService;
    readonly _serviceBrand: undefined;
    private static readonly UNTITLED_WITHOUT_ASSOCIATED_RESOURCE_REGEX;
    private readonly _onDidChangeDirty;
    readonly onDidChangeDirty: Event<IUntitledTextEditorModel>;
    private readonly _onDidChangeEncoding;
    readonly onDidChangeEncoding: Event<IUntitledTextEditorModel>;
    private readonly _onDidCreate;
    readonly onDidCreate: Event<IUntitledTextEditorModel>;
    private readonly _onWillDispose;
    readonly onWillDispose: Event<IUntitledTextEditorModel>;
    private readonly _onDidChangeLabel;
    readonly onDidChangeLabel: Event<IUntitledTextEditorModel>;
    private readonly mapResourceToModel;
    constructor(instantiationService: IInstantiationService, configurationService: IConfigurationService);
    get(resource: URI): UntitledTextEditorModel | undefined;
    getValue(resource: URI): string | undefined;
    resolve(options?: IInternalUntitledTextEditorOptions): Promise<UntitledTextEditorModel>;
    create(options?: IInternalUntitledTextEditorOptions): UntitledTextEditorModel;
    private doCreateOrGet;
    private massageOptions;
    private doCreate;
    private registerModel;
    isUntitledWithAssociatedResource(resource: URI): boolean;
    canDispose(model: UntitledTextEditorModel): true | Promise<true>;
    private doCanDispose;
}
export {};
